

<img src="https://i.imgur.com/UtEl09V.jpeg" alt="logo" align="center">

**<p align="center">  square-pass Is An Open Source Cross platform Password Manager written in python  </p>**

<p align="center">
  
<img alt="GitHub" src="https://img.shields.io/github/license/jis4nx/square-pass">
<img alt="PyPI" src="https://img.shields.io/pypi/v/square-pass">
<!--
<img alt="Arch Linux package" src="https://img.shields.io/archlinux/v/square-pass/x86_64/yay">
<img alt="PyPI - Python Version" src="https://img.shields.io/pypi/pyversions/square-pass">
-->

</p>

---

Are you suffering from trichotillomania, remembering all your different passwords for different platforms? Are you suffering from hypertension and insomnia due to the fear of your password getting stolen by the so-called secured online password managers themselves? 
Are you among those who dare not pen down their passwords, even in a securely locked diary, for fear of their spouse finding  their social-media passwords?

Fear not, my dear ladies and gentlemen! We are presenting you with  ***SquarePass***  ,a military-grade offline password manager. With SquarePass, you can store your passwords, keys, and notes safely on your local machine. With the AES-256 encryption system of SquarePass, you don't have to worry about your privacy. Access your passwords from CLI with hints or directly copy them from the database to your clipboard. Now, you don't have to struggle with remembering countless passwords and pulling your hair out, or hiding them in a secret diary stashed away on some distant shelf. Square-pass simplifies your life, making it easier, more enjoyable, and stress-free.


<div>
<img src="https://i.imgur.com/C62XIzw.gif" alt="square-pass" align="right" height="240px">
</div>
  
Square-pass in bullet speed :
  - Uses AES-256 Secure Encryption System 
  - Stores Passwords
  - Stores Keys & Numbers
  - Stores Quick Notes
  - Clipboard Support
  - Generates Secure Passwords
  - Backup Supports ( csv , json )
  - Linux & Windows Support 
  - Pip installation support 

  
</br>

### Docs: [ About ](https://github.com/) | [ Installation ](https://github.com/jis4nx/square-pass/wiki/) | [ Base Usage ](https://github.com/jis4nx/square-pass/wiki/) | [ Contribution ](https://github/)
